# Safe-DS Datasets

[![PyPI](https://img.shields.io/pypi/v/safe-ds-datasets)](https://pypi.org/project/safe-ds-datasets)
[![Main](https://github.com/Safe-DS/Datasets/actions/workflows/main.yml/badge.svg)](https://github.com/Safe-DS/Datasets/actions/workflows/main.yml)
[![codecov](https://codecov.io/gh/Safe-DS/Datasets/branch/main/graph/badge.svg?token=X5CU9V952H)](https://codecov.io/gh/Safe-DS/Datasets)
[![Documentation Status](https://readthedocs.org/projects/stdlib-examples/badge/?version=stable)](https://datasets.safeds.com)

Ready-to-use datasets for the [Safe-DS Python Library](https://github.com/Safe-DS/Library).

## Installation

Get the latest version from [PyPI](https://pypi.org/project/safe-ds-datasets):

```shell
pip install safe-ds-datasets
```

## Documentation

You can find the full documentation [here](https://datasets.safeds.com).

## Contributing

We welcome contributions from everyone. As a starting point, check the following resources:

* [Setting up a development environment](https://datasets.safeds.com/en/latest/development/environment/)
* [Project guidelines](https://datasets.safeds.com/en/latest/development/project_guidelines/)
* [Contributing page](https://github.com/Safe-DS/Datasets/contribute)

If you need further help, please [use our discussion forum][forum].

[forum]: https://github.com/orgs/Safe-DS/discussions
